@@ -147,6 +147,11 @@ from .ops import tensor_scatter_nd_update
 from .ops import diag
 from .ops import mask_select
 from .ops import eye
+from .ops import einsum
+from .ops import set_device
+from .ops import get_device
+from .ops import scatter_update
+from .ops import to_device
 # dtype
 from .ops import (
     DType, float16, float32, float64, int8, int16, int32, int64, uint8, uint16, uint32, uint64, bool, complex64,
