@@ -68,7 +68,7 @@ def set_context(**kwargs):
 
 
 def get_tensor_shape(x):
-    return list(P.Shape()(x))
+    return list(x.shape)
 
 
 # initializers
@@ -1287,9 +1287,14 @@ def resize(inputs, output_size, method, antialias):
 
 class ZeroPadding1D(Cell):
 
-    def __init__(self, padding):
+    def __init__(self, padding, data_format):
         super(ZeroPadding1D, self).__init__()
-        padding = ((0, 0), padding, (0, 0))
+        if data_format == 'channels_first':
+            padding = ((0, 0), (0, 0), padding)
+        elif data_format == 'channels_last':
+            padding = ((0, 0), padding, (0, 0))
+        else:
+            raise ValueError('data_format must be channels_first or channels_last.')
         self.pad = P.Pad(paddings=padding)
 
     def construct(self, inputs):
@@ -1300,9 +1305,14 @@ class ZeroPadding1D(Cell):
 
 class ZeroPadding2D(Cell):
 
-    def __init__(self, padding):
+    def __init__(self, padding, data_format):
         super(ZeroPadding2D, self).__init__()
-        padding = ((0, 0), padding[0], padding[1], (0, 0))
+        if data_format == 'channels_first':
+            padding = ((0, 0), (0, 0), padding[0], padding[1])
+        elif data_format == 'channels_last':
+            padding = ((0, 0), padding[0], padding[1], (0, 0))
+        else:
+            raise ValueError('data_format must be channels_first or channels_last.')
         self.pad = P.Pad(paddings=padding)
 
     def construct(self, inputs):
@@ -1311,9 +1321,14 @@ class ZeroPadding2D(Cell):
 
 class ZeroPadding3D(Cell):
 
-    def __init__(self, padding):
+    def __init__(self, padding, data_format):
         super(ZeroPadding3D, self).__init__()
-        padding = ((0, 0), padding[0], padding[1], padding[2], (0, 0))
+        if data_format == 'channels_first':
+            padding = ((0, 0), (0, 0), padding[0], padding[1], padding[2])
+        elif data_format == 'channels_last':
+            padding = ((0, 0), padding[0], padding[1], padding[2], (0, 0))
+        else:
+            raise ValueError('data_format must be channels_first or channels_last.')
         self.pad = P.Pad(paddings=padding)
 
     def construct(self, inputs):
@@ -1838,4 +1853,30 @@ class Einsum(Cell):
         self.einsum = ms.ops.Einsum(equation)
 
     def __call__(self, *args):
-        return self.einsum(tuple(args))
\ No newline at end of file
+        return self.einsum(tuple(args))
+
+def set_device(device = 'GPU', id = 0):
+    if device not in ['GPU', 'CPU', 'Ascend']:
+        raise ValueError ("In mindspore, only support 'CPU', 'GPU' and 'Ascend'.")
+    ms.context.set_context(device_target=device)
+    ms.context.set_context(device_id = id)
+
+def scatter_update(tensor, indices, updates):
+    if not isinstance(tensor,  ms.Tensor) or not isinstance(updates, ms.Tensor):
+        raise TypeError("tensor, updates should be Tensor, but got tensor type is {}, "
+                        "and updates type is {}.".format(type(tensor), type(updates)))
+    indices = ms.Tensor(indices)
+    shape = indices.shape
+    indices = ms.ops.reshape(indices, (shape[0], 1))
+    op = ms.ops.TensorScatterUpdate()
+    return op(tensor, indices, updates)
+
+def get_device():
+    device = ms.context.get_context("device_target")
+    id = ms.context.get_context("device_id")
+    device = device + ":" +str(id)
+    return device
+
+def to_device(tensor, device = 'GPU', id = 0):
+
+    return tensor
