@@ -83,7 +83,7 @@ def set_context(**kwargs):
 
 
 def get_tensor_shape(x):
-    return pd.shape(x)
+    return list(x.shape)
 
 
 # initializers
@@ -1211,7 +1211,10 @@ def floor(x):
 
 
 def gather(params, indices, axis=None):
-
+    if axis is None:
+        axis = 0
+    if axis < 0:
+        axis = len(params.shape) + axis
     return pd.gather(params, indices, axis)
 
 
@@ -1313,34 +1316,64 @@ def resize(inputs, output_size, method, antialias):
     return Resize(output_size, method, antialias)(inputs)
 
 
+def channels_switching(data_format, dim='2d', padding=None):
+    if dim == '1d':
+        if data_format == 'channels_first':
+            out = 'NCL'
+        if data_format == 'channels_last':
+            out = 'NLC'
+        pads = padding
+    if dim == '2d':
+        if data_format == 'channels_first':
+            out = 'NCHW'
+        if data_format == 'channels_last':
+            out = 'NHWC'
+        pads = [padding[1][0], padding[1][1], padding[0][0], padding[0][1]]
+    if dim == '3d':
+        if data_format == 'channels_first':
+            out = 'NCDHW'
+        if data_format == 'channels_last':
+            out = 'NDHWC'
+        pads = [padding[2][0], padding[2][1],
+                padding[1][0], padding[1][1],
+                padding[0][0], padding[0][1]]
+    return out, pads
+
+
 class ZeroPadding1D(object):
 
-    def __init__(self, padding):
-        padding = ((0, 0), padding, (0, 0))
-        self.pad = Pad(paddings=padding)
+    def __init__(self, padding, data_format):
+        self.padding = padding
+        self.data_format = data_format
 
     def __call__(self, inputs):
-        return self.pad(inputs)
+        data_format, padding = channels_switching(self.data_format, '1d', self.padding)
+        out = pd.nn.functional.pad(inputs, padding, mode='constant', value=0.0, data_format=data_format)
+        return out
 
 
 class ZeroPadding2D(object):
 
-    def __init__(self, padding):
-        padding = ((0, 0), padding[0], padding[1], (0, 0))
-        self.pad = Pad(paddings=padding)
+    def __init__(self, padding, data_format):
+        self.padding = padding
+        self.data_format = data_format
 
     def __call__(self, inputs):
-        return self.pad(inputs)
+        data_format, padding = channels_switching(self.data_format, '2d', self.padding)
+        out = pd.nn.functional.pad(inputs, padding, mode='constant', value=0.0, data_format=data_format)
+        return out
 
 
 class ZeroPadding3D(object):
 
-    def __init__(self, padding):
-        padding = ((0, 0), padding[0], padding[1], padding[2], (0, 0))
-        self.pad = Pad(paddings=padding)
+    def __init__(self, padding, data_format):
+        self.padding = padding
+        self.data_format = data_format
 
     def __call__(self, inputs):
-        return self.pad(inputs)
+        data_format, padding = channels_switching(self.data_format, '3d', self.padding)
+        out = pd.nn.functional.pad(inputs, padding, mode='constant', value=0.0, data_format=data_format)
+        return out
 
 
 class Sign(object):
@@ -1856,3 +1889,24 @@ class Einsum(object):
     def __call__(self, *args):
         return einsum(self.equation, *args)
 
+
+def set_device(device = 'GPU', id = 0):
+    device = device.lower()
+    if device == 'gpu':
+        device = device + ':' + str(id)
+    paddle.device.set_device(device)
+
+def scatter_update(tensor, indices, updates):
+
+    return pd.scatter(tensor, indices, updates)
+
+def get_device():
+
+    return paddle.device.get_device()
+
+def to_device(tensor, device = 'GPU', id = 0):
+    device = device.upper()
+    if device == 'GPU':
+        return paddle.to_tensor(tensor, place=paddle.CUDAPlace(id))
+    if device == 'CPU':
+        return paddle.to_tensor(tensor, place=paddle.CPUPlace())
\ No newline at end of file
