@@ -547,11 +547,13 @@ class ReduceMax(object):
 
     def __call__(self, inputs):
         if self.axis is not None:
-            out = inputs
-            for dim in self.axis[-1]:
-                print(dim)
-                out = torch.max(out, dim=dim, keepdim=self.keepdims).values
-            return out
+            if isinstance(self.axis, (list, tuple)):
+                out = inputs
+                for dim in self.axis[::-1]:
+                    out = torch.max(out, dim=dim, keepdim=self.keepdims).values
+                return out
+            else:
+                return torch.max(inputs, dim=self.axis, keepdim=self.keepdims).values
         else:
             return torch.max(inputs)
 
@@ -1161,8 +1163,13 @@ def resize(inputs, output_size, method, antialias):
 
 class ZeroPadding1D(object):
 
-    def __init__(self, padding):
-        padding = ((0, 0), padding, (0, 0))
+    def __init__(self, padding, data_format):
+        if data_format == 'channels_first':
+            padding = ((0, 0), (0, 0), padding)
+        elif data_format == 'channels_last':
+            padding = ((0, 0), padding, (0, 0))
+        else:
+            raise ValueError('data_format must be channels_first or channels_last.')
         self.pad = Pad(paddings=padding)
 
     def __call__(self, inputs):
@@ -1171,8 +1178,13 @@ class ZeroPadding1D(object):
 
 class ZeroPadding2D(object):
 
-    def __init__(self, padding):
-        padding = ((0, 0), padding[0], padding[1], (0, 0))
+    def __init__(self, padding, data_format):
+        if data_format == 'channels_first':
+            padding = ((0, 0), (0, 0), padding[0], padding[1])
+        elif data_format == 'channels_last':
+            padding = ((0, 0), padding[0], padding[1], (0, 0))
+        else:
+            raise ValueError('data_format must be channels_first or channels_last.')
         self.pad = Pad(paddings=padding)
 
     def __call__(self, inputs):
@@ -1181,8 +1193,13 @@ class ZeroPadding2D(object):
 
 class ZeroPadding3D(object):
 
-    def __init__(self, padding):
-        padding = ((0, 0), padding[0], padding[1], padding[2], (0, 0))
+    def __init__(self, padding, data_format):
+        if data_format == 'channels_first':
+            padding = ((0, 0), (0, 0), padding[0], padding[1], padding[2])
+        elif data_format == 'channels_last':
+            padding = ((0, 0), padding[0], padding[2], padding[1], (0, 0))
+        else:
+            raise ValueError('data_format must be channels_first or channels_last.')
         self.pad = Pad(paddings=padding)
 
     def __call__(self, inputs):
@@ -1639,7 +1656,7 @@ def is_tensor(x):
 
 def tensor_scatter_nd_update(tensor, indices, updates):
     tensor = torch.tensor(tensor)
-    indices = torch.tensor(indices)
+    indices = torch.tensor(indices, dtype=torch.long)
     updates = torch.tensor(updates)
     indices = torch.flatten(indices)
     tensor[indices] = updates
@@ -1666,6 +1683,8 @@ def mask_select(x, mask, axis = 0):
         return x[:,:,:, mask]
 
 def eye(n, m=None, dtype=None):
+    if m is None:
+        m = n
     return torch.eye(n = n, m = m, dtype =dtype)
 
 
@@ -1679,4 +1698,32 @@ class Einsum(object):
         self.equation = equation
 
     def __call__(self, *args):
-        return torch.einsum(self.equation, *args)
\ No newline at end of file
+        return torch.einsum(self.equation, *args)
+
+def set_device(device = 'GPU', id = 0):
+    if device == 'GPU':
+        torch.set_default_tensor_type('torch.cuda.FloatTensor')
+        torch.cuda.set_device(id)
+
+def scatter_update(tensor, indices, updates):
+    tensor = torch.tensor(tensor)
+    indices = torch.tensor(indices, dtype=torch.long)
+    updates = torch.tensor(updates)
+    tensor[indices] = updates
+    return tensor
+
+def get_device():
+    try:
+        id = torch.cuda.current_device()
+        device = 'GPU:' + str(id)
+        return device
+    except:
+        device = 'CPU'
+        return device
+
+def to_device(tensor, device='GPU', id=0):
+    device = device.lower()
+    if device == 'gpu':
+        device = 'cuda' + ':' + str(id)
+    tensor = tensor.detach().to(device)
+    return tensor
\ No newline at end of file
