@@ -776,7 +776,7 @@ class MaxPool1d(object):
 
     def __init__(self, ksize, strides, padding, data_format=None):
         self.data_format, self.padding = preprocess_1d_format(data_format=data_format, padding=padding)
-        self.max_pool1d = MaxPool(ksize, strides, padding, data_format)
+        self.max_pool1d = MaxPool([ksize,], strides, padding, data_format)
 
     def __call__(self, inputs):
         return self.max_pool1d(inputs)
@@ -792,6 +792,8 @@ class MaxPool(object):
         elif data_format in ['channels_first', 'NCL', 'NCW', 'NCHW', 'NCDHW']:
             self.data_format = 'channels_first'
         self.padding = padding
+        if self.padding in ['VALID', 'valid']:
+            self.padding = 0
 
     def __call__(self, inputs):
         if self.data_format == 'channels_last':
@@ -805,12 +807,12 @@ class MaxPool(object):
             if self.padding in ['SAME', 'same']:
                 out = self.maxpool2d_same_padding(inputs)
             else:
-                out = F.max_pool2d(inputs, self.ksize, (self.strides[1], self.strides[2]), padding=self.padding)
+                out = F.max_pool2d(inputs, self.ksize, self.strides, padding=self.padding)
         if len(inputs.shape) == 5:
             if self.padding in ['SAME', 'same']:
                 out = self.maxpool3d_same_padding(inputs)
             else:
-                out = F.max_pool3d(inputs, self.ksize, (self.strides[1], self.strides[2], self.strides[3]), padding=self.padding)
+                out = F.max_pool3d(inputs, self.ksize, self.strides, padding=self.padding)
 
         if self.data_format == 'channels_last':
             return nchw_to_nhwc(out)
@@ -824,23 +826,21 @@ class MaxPool(object):
         return F.max_pool1d(input, self.ksize, self.strides, padding=(padding_rows // 2))
 
     def maxpool2d_same_padding(self, input):
-        strides = [self.strides[1], self.strides[2]]
-        rows_odd, cols_odd, padding_rows, padding_cols = same_padding(input, self.ksize, strides, (1, 1))
+        rows_odd, cols_odd, padding_rows, padding_cols = same_padding(input, self.ksize, self.strides, (1, 1))
         if rows_odd or cols_odd:
             # TODO The fill value for maxpool is -INF.
             input = F.pad(input, [0, int(rows_odd), 0, int(cols_odd)], 'constant', float('-inf'))
 
-        return F.max_pool2d(input, self.ksize, strides, padding=(padding_rows // 2, padding_cols // 2))
+        return F.max_pool2d(input, self.ksize, self.strides, padding=(padding_rows // 2, padding_cols // 2))
 
     def maxpool3d_same_padding(self, input):
-        strides = [self.strides[1], self.strides[2], self.strides[3]]
         rows_odd, cols_odd, depth_odd, padding_rows, padding_cols, padding_depth = same_padding(
-            input, self.ksize, strides, (1, 1, 1)
+            input, self.ksize, self.strides, (1, 1, 1)
         )
         if rows_odd or cols_odd or depth_odd:
             input = F.pad(input, [0, int(cols_odd), 0, int(rows_odd), 0, int(depth_odd)], 'constant', float('-inf'))
         return F.max_pool3d(
-                input, self.ksize, strides, padding=(padding_rows // 2, padding_cols // 2, padding_depth // 2)
+                input, self.ksize, self.strides, padding=(padding_rows // 2, padding_cols // 2, padding_depth // 2)
         )
 
 
@@ -878,7 +878,7 @@ class AvgPool1d(object):
 
     def __init__(self, ksize, strides, padding, data_format=None):
         self.data_format, self.padding = preprocess_1d_format(data_format=data_format, padding=padding)
-        self.avg_poo1d = AvgPool(ksize, strides, padding, data_format)
+        self.avg_poo1d = AvgPool([ksize, ], strides, padding, data_format)
 
     def __call__(self, inputs):
         return self.avg_poo1d(inputs)
@@ -894,6 +894,8 @@ class AvgPool(object):
         elif data_format in ['channels_first', 'NCL', 'NCW', 'NCHW', 'NCDHW']:
             self.data_format = 'channels_first'
         self.padding = padding
+        if self.padding in ['VALID', 'valid']:
+            self.padding = 0
 
     def __call__(self, inputs):
         if self.data_format == 'channels_last':
@@ -907,12 +909,12 @@ class AvgPool(object):
             if self.padding in ['SAME', 'same']:
                 out = self.avgpool2d_same_padding(inputs)
             else:
-                out = F.avg_pool2d(inputs, self.ksize, (self.strides[1], self.strides[2]), padding=self.padding)
+                out = F.avg_pool2d(inputs, self.ksize, self.strides, padding=self.padding)
         if len(inputs.shape) == 5:
             if self.padding in ['SAME', 'same']:
                 out = self.avgpool3d_same_padding(inputs)
             else:
-                out = F.avg_pool3d(inputs, self.ksize, (self.strides[1], self.strides[2], self.strides[3]), padding=self.padding)
+                out = F.avg_pool3d(inputs, self.ksize, self.strides, padding=self.padding)
 
         if self.data_format == 'channels_last':
             return nchw_to_nhwc(out)
@@ -926,23 +928,21 @@ class AvgPool(object):
         return F.avg_pool1d(input, self.ksize, self.strides, padding=(padding_rows // 2))
 
     def avgpool2d_same_padding(self, input):
-        strides = [self.strides[1], self.strides[2]]
-        rows_odd, cols_odd, padding_rows, padding_cols = same_padding(input, self.ksize, strides, (1, 1))
+        rows_odd, cols_odd, padding_rows, padding_cols = same_padding(input, self.ksize, self.strides, (1, 1))
         if rows_odd or cols_odd:
             # TODO The fill value for maxpool is -INF.
             input = F.pad(input, [0, int(rows_odd), 0, int(cols_odd)], mode='replicate')
 
-        return F.avg_pool2d(input, self.ksize, strides, padding=(padding_rows // 2, padding_cols // 2))
+        return F.avg_pool2d(input, self.ksize, self.strides, padding=(padding_rows // 2, padding_cols // 2))
 
     def avgpool3d_same_padding(self, input):
-        strides = [self.strides[1], self.strides[2], self.strides[3]]
         rows_odd, cols_odd, depth_odd, padding_rows, padding_cols, padding_depth = same_padding(
-            input, self.ksize, strides, (1, 1, 1)
+            input, self.ksize, self.strides, (1, 1, 1)
         )
         if rows_odd or cols_odd or depth_odd:
             input = F.pad(input, [0, int(cols_odd), 0, int(rows_odd), 0, int(depth_odd)], mode='replicate')
         return F.avg_pool3d(
-                input, self.ksize, strides, padding=(padding_rows // 2, padding_cols // 2, padding_depth // 2)
+                input, self.ksize, self.strides, padding=(padding_rows // 2, padding_cols // 2, padding_depth // 2)
         )
 
 
@@ -1104,25 +1104,22 @@ def pool(input, window_shape, pooling_type, strides=None, padding='VALID', data_
 
 class DepthwiseConv2d(object):
 
-    def __init__(self, strides, padding, data_format=None, dilations=None, ksize=None, channel_multiplier=1):
+    def __init__(self, strides, padding, data_format=None, dilations=None, ksize=None, channel_multiplier=1, in_channels=None):
         self.data_format, self.padding = preprocess_2d_format(data_format, padding)
-        if self.data_format == 'NHWC':
-            self._stride = (strides[1], strides[2])
-        if self.data_format == 'NCHW':
-            self._stride = (strides[2], strides[3])
-        self.dilations = dilations
+        if self.data_format is 'NHWC':
+            self.strides = (1, strides[0], strides[1], 1)
+            self.dilations = (1, dilations[0], dilations[1], 1)
+        elif self.data_format is 'NCHW':
+            self.strides = (1, 1, strides[0], strides[1])
+            self.dilations = (1, 1, dilations[0], dilations[1])
+        self.depthwise = Conv2D(padding=self.padding, strides=self.strides, data_format=self.data_format,
+                                dilations=self.dilations, groups=in_channels)
+        self.pointwise = Conv2D(strides=(1, 1, 1, 1), padding=self.padding, data_format=self.data_format, dilations=self.dilations, k_size=1)
 
     def __call__(self, input, filter, point_filter=None):
-        if self.data_format == 'NHWC':
-            input = nhwc_to_nchw(input)
-        channel = input.shape[1]
+        depthwise_conv = self.depthwise(input, filter)
+        pointwise_conv = self.pointwise(depthwise_conv, point_filter)
 
-        depthwise_conv = F.conv2d(input, filter, bias=None, stride=self._stride, padding=self.padding,
-                                  dilation=self.dilations, groups=channel)
-        pointwise_conv = F.conv2d(depthwise_conv, point_filter, padding=self.padding)
-
-        if self.data_format == 'NHWC':
-            pointwise_conv = nchw_to_nhwc(pointwise_conv)
         return pointwise_conv
 
 
@@ -1240,7 +1237,7 @@ class Conv1d_transpose(object):
             out = F.conv_transpose1d(
                 input,
                 weight=filters,
-                padding=0,
+                padding=(0 if isinstance(self.padding, str) else self.padding),
                 stride=self.stride,
                 dilation=self.dilations
             )
@@ -1319,7 +1316,7 @@ class Conv2d_transpose(object):
             out = F.conv_transpose2d(
                 input,
                 weight=filters,
-                padding=0,
+                padding=(0 if isinstance(self.padding, str) else self.padding),
                 stride=self.strides,
                 dilation=self.dilations
             )
@@ -1399,7 +1396,7 @@ class Conv3d_transpose(object):
             out = F.conv_transpose3d(
                 input,
                 weight=filters,
-                padding=0,
+                padding=(0 if isinstance(self.padding, str) else self.padding),
                 stride=self.strides,
                 dilation=self.dilations
             )
@@ -1934,7 +1931,7 @@ class rnnbase(Module):
             )
 
     def check_hidden(self, h, batch_size):
-        expected_hidden_size = (self.num_layers * self.bidirect, batch_size, self.hidden_size)
+        expected_hidden_size = (self.num_layers * self.num_directions, batch_size, self.hidden_size)
         if h.shape != expected_hidden_size:
             raise ValueError('Expected hidden size {}, got {}.'.format(expected_hidden_size, h.shape))
 
@@ -2182,7 +2179,7 @@ class PReLU(object):
         self.data_format = data_format
 
     def __call__(self, input, weight):
-        weight = weight.to(input.device)
+        # weight = weight.to(input.device)
         return torch.prelu(input, weight)
 
 
