@@ -11,9 +11,10 @@ import inspect
 from mindspore import context
 import numpy
 from mindspore.common.api import _pynative_executor
-from mindspore.common.parameter import Parameter
 from collections import OrderedDict, abc as container_abcs
-__all__ = ['Module', 'Sequential', 'ModuleList', 'ModuleDict']
+
+
+__all__ = ['Module', 'Sequential', 'ModuleList', 'ModuleDict', 'Parameter', 'ParameterList', 'ParameterDict']
 
 _global_layer_name_dict = {}
 _global_layer_node = []
@@ -127,55 +128,8 @@ class Module(Cell):
             shape_mem = tlx.get_tensor_shape(tensors)
         return shape_mem
 
-    def __call__(self, *args, **kwargs):
-        if self.__class__.construct is Cell.construct:
-            logger.warning(f"The '{self.__class__}' does not override the method 'construct', "
-                           f"will call the super class(Cell) 'construct'.")
-        if kwargs:
-            bound_arguments = inspect.signature(self.construct).bind(*args, **kwargs)
-            bound_arguments.apply_defaults()
-            args = bound_arguments.args
-            kwargs = bound_arguments.kwargs
-
-        # Run in Graph mode.
-        if context._get_mode() == context.GRAPH_MODE:
-            self._check_construct_args(*args, **kwargs)
-            if self.enable_hook:
-                raise ValueError("For 'Cell', it's not support hook function in graph mode, please use "
-                                 "context.set_context to set pynative mode.")
-            out = self.compile_and_run(*args)
-            return out
-
-        # Run in PyNative mode.
-        if _pynative_executor.is_top_cell():
-            _pynative_executor.set_lazy_build(True)
-            # There many Casts in parameter_broadcast. Enable lazy_build and build faster.
-            self._do_parameter_broadcast()
-
-        for item in args:
-            if isinstance(item, ms.Tensor) and item.has_init:
-                item.init_data()
-            elif isinstance(item, numpy.ndarray):
-                raise TypeError("For 'Cell', inputs should not be numpy array.")
-        if self.requires_grad is True:
-            _pynative_executor.set_grad_flag(True)
-        _pynative_executor.new_graph(self, *args, **kwargs)
-        cast_inputs = self.auto_cast_inputs(args)
-
-        with self.CellGuard():
-            try:
-                output = self.run_construct(cast_inputs, kwargs)
-            except Exception as err:
-                _pynative_executor.clear_res()
-                raise err
-
-        if _pynative_executor.is_top_cell():
-            _pynative_executor.execute_lazy_task()
-
-        if isinstance(output, Parameter):
-            output = output.data
-        _pynative_executor.end_graph(self, output, *args, **kwargs)
-        return output
+    # def __call__(self, *args, **kwargs):
+    ## TODO With MindSpore __call__, refactoring is required when there are special cases to consider
 
     def set_train(self):
         """
@@ -323,7 +277,9 @@ class Module(Cell):
             in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
         node_index = len(_global_layer_node)
 
-        new_node = ModuleNode(self, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(self))
+        new_node = ModuleNode(
+            self, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(self)
+        )
         _global_layer_node.append(new_node)
         for idx, tensor in enumerate(outputs_list):
             tensor._info = (new_node, idx)
@@ -424,9 +380,32 @@ class Sequential(Module):
 
     def forward(self, input_data):
         for layer in self.layer_list:
+            inputs = input_data
             input_data = layer(input_data)
+            outputs = input_data
+            if not self._nodes_fixed and self._build_graph:
+                self._add_seq_node(inputs, outputs, layer)
+        self._nodes_fixed = True
         return input_data
 
+    def _add_seq_node(self, input_tensors, output_tensors, layer):
+        inputs_list = tolist(input_tensors)
+        outputs_list = tolist(output_tensors)
+        if layer.__class__.__name__ in tlx.layers.inputs.__all__:
+            in_nodes = []
+            in_tensor_idxes = [0]
+        else:
+            in_nodes = [tensor._info[0] for tensor in inputs_list]
+            in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
+        node_index = len(_global_layer_node)
+
+        new_node = ModuleNode(
+            layer, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(layer)
+        )
+        _global_layer_node.append(new_node)
+        for idx, tensor in enumerate(outputs_list):
+            tensor._info = (new_node, idx)
+
 
 class ModuleList(Module):
     """
@@ -468,7 +447,7 @@ class ModuleList(Module):
     >>> layer_list.append(d3)
     """
 
-    def __init__(self, modules = None):
+    def __init__(self, modules=None):
         super(ModuleList, self).__init__()
         if modules is not None:
             self.extend(modules)
@@ -546,7 +525,7 @@ class ModuleList(Module):
 
 class ModuleDict(Module):
 
-    def __init__(self, modules = None):
+    def __init__(self, modules=None):
         super(ModuleDict, self).__init__()
         if modules is not None:
             self.update(modules)
@@ -629,6 +608,171 @@ class ModuleDict(Module):
                 self[m[0]] = m[1]
 
 
+def Parameter(data=None, requires_grad=True, name=None):
+
+    return ms.Parameter(default_input=data, requires_grad=requires_grad, name=name)
+
+
+class ParameterList(Module):
+
+    def __init__(self, parameters=None):
+        super(ParameterList, self).__init__()
+        if parameters is not None:
+            self += parameters
+
+    def _get_abs_string_index(self, idx):
+        if not (-len(self) <= idx < len(self)):
+            raise IndexError('index {} is out of range'.format(idx))
+        if idx < 0:
+            idx += len(self)
+        return str(idx)
+
+    def __getitem__(self, idx):
+        if isinstance(idx, slice):
+            return self.__class__(list(self._params.values())[idx])
+        else:
+            idx = self._get_abs_string_index(idx)
+            return self._params[str(idx)]
+
+    def __setitem__(self, idx, parameter):
+        idx = self._get_abs_string_index(idx)
+        self._params[str(idx)] = parameter
+
+    def __setattr__(self, key, value):
+        super(ParameterList, self).__setattr__(key, value)
+
+    def __len__(self):
+        return len(self._params)
+
+    def __iter__(self):
+        return iter(self._params.values())
+
+    def __iadd__(self, parameters):
+        return self.extend(parameters)
+
+    def __dir__(self):
+        keys = super(ParameterList, self).__dir__()
+        keys = [key for key in keys if not key.isdigit()]
+        return keys
+
+    def append(self, parameter):
+        self._params[str(len(self))] = parameter
+        return self
+
+    def extend(self, parameters):
+        if not isinstance(parameters, container_abcs.Iterable):
+            raise TypeError(
+                "ParameterList.extend should be called with an "
+                "iterable, but got " + type(parameters).__name__
+            )
+        offset = len(self)
+        for i, para in enumerate(parameters):
+            self._params[str(offset + i)] = para
+        return self
+
+    def __call__(self, input):
+        raise RuntimeError('ParameterList should not be called.')
+
+
+class ParameterDict(Module):
+
+    def __init__(self, parameters=None):
+        super(ParameterDict, self).__init__()
+        if parameters is not None:
+            self.update(parameters)
+
+    def __getitem__(self, key):
+        return self._params[key]
+
+    def __setitem__(self, key, parameter):
+        self._params[key] = parameter
+
+    def __delitem__(self, key):
+        del self._params[key]
+
+    def __setattr__(self, key, value):
+        super(ParameterDict, self).__setattr__(key, value)
+
+    def __len__(self) -> int:
+        return len(self._params)
+
+    def __reversed__(self):
+        return reversed(list(self._params.keys()))
+
+    def __iter__(self):
+        return iter(self._params.keys())
+
+    def copy(self):
+        return ParameterDict(self._params.copy())
+
+    def __contains__(self, key):
+        return key in self._params
+
+    def setdefault(self, key, default=None):
+        if key in self._params:
+            return self._params[key]
+        self[key] = default
+        return self._params[key]
+
+    def clear(self):
+        return self._params.clear()
+
+    def pop(self, key):
+        v = self[key]
+        del self[key]
+        return v
+
+    def popitem(self):
+        return self._params.popitem()
+
+    def get(self, key, default=None):
+        return self._params.get(key, default)
+
+    def fromkeys(self, keys, default=None):
+        return ParameterDict(self._params.fromkeys(keys, default))
+
+    def keys(self):
+        return self._params.keys()
+
+    def items(self):
+        return self._params.items()
+
+    def values(self):
+        return self._params.values()
+
+    def update(self, parameters):
+        if not isinstance(parameters, container_abcs.Iterable):
+            raise TypeError(
+                "ParametersDict.update should be called with an "
+                "iterable of key/value pairs, but got " + type(parameters).__name__
+            )
+
+        if isinstance(parameters, (OrderedDict, ParameterDict)):
+            for key, parameter in parameters.items():
+                self[key] = parameter
+        elif isinstance(parameters, container_abcs.Mapping):
+            for key, parameter in sorted(parameters.items()):
+                self[key] = parameter
+        else:
+            for j, p in enumerate(parameters):
+                if not isinstance(p, container_abcs.Iterable):
+                    raise TypeError(
+                        "ParameterDict update sequence element "
+                        "#" + str(j) + " should be Iterable; is" + type(p).__name__
+                    )
+                print(p)
+                if not len(p) == 2:
+                    raise ValueError(
+                        "ParameterDict update sequence element "
+                        "#" + str(j) + " has length " + str(len(p)) + "; 2 is required"
+                    )
+                # parameters as length-2 list too cumbersome to type, see ModuleDict.update comment
+                self[p[0]] = p[1]  # type: ignore[assignment]
+
+    def __call__(self, input):
+        raise RuntimeError('ParameterDict should not be called.')
+
+
 def _valid_index(layer_num, index):
     if not isinstance(index, int):
         raise TypeError("Index {} is not int type")
