@@ -4,13 +4,13 @@
 from .common import check_parameter, processing_act, str2init, tolist, construct_graph, ModuleNode, select_attrs
 from .common import _save_weights, _load_weights, _save_standard_weights_dict, _load_standard_weights_dict
 from collections import OrderedDict, abc as container_abcs
-from collections import OrderedDict
+import warnings
 import time
 import tensorlayerx as tlx
 import tensorflow as tf
 from tensorlayerx.nn.layers.utils import (get_variable_with_initializer, random_normal)
 
-__all__ = ['Module', 'Sequential', 'ModuleList', 'ModuleDict']
+__all__ = ['Module', 'Sequential', 'ModuleList', 'ModuleDict', 'Parameter', 'ParameterList', 'ParameterDict']
 
 _global_layer_name_dict = {}
 _global_layer_node = []
@@ -55,6 +55,8 @@ class Module(object):
     def __init__(self, name=None, act=None, *args, **kwargs):
         self._params = OrderedDict()
         self._layers = OrderedDict()
+        # self._params_list = OrderedDict()
+        # self._params_dict = OrderedDict()
         self._params_status = OrderedDict()
         self._parameter_layout_dict = {}
         self._create_time = int(time.time() * 1e9)
@@ -102,6 +104,10 @@ class Module(object):
         # Layer training state
         self.is_train = True
 
+        # weights check state
+        self._check = False
+        self.trainable = True
+
     def extend_repr(self):
         """
         Sets the extended representation of the Module.
@@ -142,6 +148,12 @@ class Module(object):
                 raise TypeError("Expected type is Module, but got Parameter.")
             self.insert_param_to_layer(name, value)
 
+        # elif isinstance(value, ParameterList):
+        #     self.set_attr_for_parameter_tuple(name, value)
+        #
+        # elif isinstance(value, ParameterDict):
+        #     self.set_attr_for_parameter_dict(name, value)
+
         elif isinstance(value, Module):
             if layers is None:
                 raise AttributeError("Can not assign layers before Module.__init__() call.")
@@ -149,22 +161,28 @@ class Module(object):
                 del self.__dict__[name]
             if params and name in params:
                 raise TypeError("Expected type is Parameter, but got Module.")
-            # TODO Automatic shape inference when the user does not enter inchannels.
-            # if value._built is False:
-            #     raise AttributeError(
-            #         "The registered layer `{}` should be built in advance. "
-            #         "Do you forget to pass the keyword argument 'in_channels'? ".format(value.name)
-            #     )
             layers[name] = value
         else:
             object.__setattr__(self, name, value)
 
     def __call__(self, inputs, *args, **kwargs):
+        if self._check == False:
+            self.train_weights_check()
+            self._check = True
 
         output = self.forward(inputs, *args, **kwargs)
-
         return output
 
+    def train_weights_check(self):
+        _param_name = []
+        for w in self.trainable_weights:
+            if w.name not in _param_name:
+                _param_name.append(w.name)
+            else:
+                raise Exception("parameter name [{}] have be been used. "
+                "In training, the name of layer can't be same."
+                "Please check the layers name".format(w.name))
+
     def forward(self, *inputs, **kwargs):
         raise Exception("The forward method must be implemented by inherited class")
 
@@ -237,6 +255,47 @@ class Module(object):
             if isinstance(layer, Module):
                 layer.is_train = is_train
 
+    # def set_attr_for_parameter_dict(self, name, value):
+    #     """Set attr for parameter in ParameterDict."""
+    #     params = self.__dict__.get('_params')
+    #     params_dict = self.__dict__.get('_params_dict')
+    #     if params is None:
+    #         raise AttributeError("For 'Module', can not assign params before Module.__init__() is called.")
+    #     exist_names = set("")
+    #     for item in value:
+    #         self.insert_param_to_layer(item, value[item], check_name=False)
+    #         if item in exist_names:
+    #             raise ValueError("The value {} , its name '{}' already exists.".
+    #                              format(value[item], item))
+    #         exist_names.add(item)
+    #
+    #     if name in self.__dict__:
+    #         del self.__dict__[name]
+    #     if name in params:
+    #         del params[name]
+    #     params_dict[name] = value
+    #
+    # def set_attr_for_parameter_tuple(self, name, value):
+    #     """Set attr for parameter in ParameterTuple."""
+    #     params = self.__dict__.get('_params')
+    #     params_list = self.__dict__.get('_params_list')
+    #     if params is None:
+    #         raise AttributeError("For 'Module', can not assign params before Module.__init__() is called.")
+    #     exist_names = set("")
+    #
+    #     for item in value:
+    #         self.insert_param_to_layer(item.name, item, check_name=False)
+    #         if item.name in exist_names:
+    #             raise ValueError("The value {} , its name '{}' already exists.".
+    #                              format(value, item.name))
+    #         exist_names.add(item.name)
+    #
+    #     if name in self.__dict__:
+    #         del self.__dict__[name]
+    #     if name in params:
+    #         del params[name]
+    #     params_list[name] = value
+
     def set_train(self):
         """Set this network in training mode. After calling this method,
         all layers in network are in training mode, in particular, BatchNorm, Dropout, etc.
@@ -295,7 +354,6 @@ class Module(object):
             Determines whether the name input is compatible. Default: True.
 
         """
-
         if not param_name:
             raise KeyError("The name of parameter should not be null.")
         if check_name and '.' in param_name:
@@ -329,6 +387,15 @@ class Module(object):
             params_status = self.__dict__['_params_status']
             if name in params_status:
                 return params_status[name]
+        # if '_params_list' in self.__dict__:
+        #     params_list = self.__dict__['_params_list']
+        #     if name in params_list:
+        #         para_list = params_list[name]
+        #         return para_list
+        # if '_params_dict' in self.__dict__:
+        #     params_dict = self.__dict__['_params_dict']
+        #     if name in params_dict:
+        #         return params_dict[name]
         raise AttributeError("'{}' object has no attribute '{}'.".format(type(self).__name__, name))
 
     def __delattr__(self, name):
@@ -611,7 +678,9 @@ class Module(object):
             in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
         node_index = len(_global_layer_node)
 
-        new_node = ModuleNode(self, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(self))
+        new_node = ModuleNode(
+            self, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(self)
+        )
         _global_layer_node.append(new_node)
         for idx, tensor in enumerate(outputs_list):
             tensor._info = (new_node, idx)
@@ -706,9 +775,32 @@ class Sequential(Module):
 
     def forward(self, input_data):
         for layer in self.layer_list:
+            inputs = input_data
             input_data = layer(input_data)
+            outputs = input_data
+            if not self._nodes_fixed and self._build_graph:
+                self._add_seq_node(inputs, outputs, layer)
+        self._nodes_fixed = True
         return input_data
 
+    def _add_seq_node(self, input_tensors, output_tensors, layer):
+        inputs_list = tolist(input_tensors)
+        outputs_list = tolist(output_tensors)
+        if layer.__class__.__name__ in tlx.layers.inputs.__all__:
+            in_nodes = []
+            in_tensor_idxes = [0]
+        else:
+            in_nodes = [tensor._info[0] for tensor in inputs_list]
+            in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
+        node_index = len(_global_layer_node)
+
+        new_node = ModuleNode(
+            layer, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(layer)
+        )
+        _global_layer_node.append(new_node)
+        for idx, tensor in enumerate(outputs_list):
+            tensor._info = (new_node, idx)
+
 
 class ModuleList(Module):
     """
@@ -750,7 +842,7 @@ class ModuleList(Module):
     >>> layer_list.append(d3)
     """
 
-    def __init__(self, modules = None):
+    def __init__(self, modules=None):
         super(ModuleList, self).__init__()
         if modules is not None:
             self.extend(modules)
@@ -882,7 +974,7 @@ class ModuleDict(Module):
 
     """
 
-    def __init__(self, modules = None):
+    def __init__(self, modules=None):
         super(ModuleDict, self).__init__()
         if modules is not None:
             self.update(modules)
@@ -965,6 +1057,305 @@ class ModuleDict(Module):
                 self[m[0]] = m[1]
 
 
+class Parameter(Module):
+    """This function creates a parameter. The parameter is a learnable variable, which can have gradient, and can be optimized.
+
+    Parameters
+    ----------
+    data : Tensor
+        parameter tensor
+    requires_grad : bool
+        if the parameter requires gradient. Default: True
+
+    Returns
+    -------
+        Parameter
+
+    Examples
+    ----------
+    >>> import tensorlayerx as tlx
+    >>> para = tlx.nn.Parameter(data=tlx.ones((5,5)), requires_grad=True)
+
+    """
+
+    def __new__(self, data=None, name=None):
+        instance = super().__new__(self)
+        if name is None:
+            prefix = 'parameter'
+
+            if _global_layer_name_dict.get(prefix) is not None:
+                _global_layer_name_dict[prefix] += 1
+                name = prefix + '_' + str(_global_layer_name_dict[prefix])
+            else:
+                _global_layer_name_dict[prefix] = 0
+                name = prefix
+            while True:
+                if _global_layer_name_dict.get(name) is None:
+                    break
+                _global_layer_name_dict[prefix] += 1
+                name = prefix + '_' + str(_global_layer_name_dict[prefix])
+        else:
+            if _global_layer_name_dict.get(name) is not None:
+                pass
+            else:
+                _global_layer_name_dict[name] = 0
+        if data is None:
+            return instance
+        else:
+            return instance(data, name)
+
+    def __call__(self, data=None, name=None, **kwargs):
+        return tf.Variable(initial_value=data, name=name)
+
+
+class ParameterList(Module):
+    """Holds parameters in a list.
+
+    ParameterList can be indexed like a regular Python list. Support
+    '__getitem__', '__setitem__', '__delitem__', '__len__', '__iter__' and '__iadd__'.
+
+    Parameters
+    ----------
+        Parameters : list
+            List of Parameter.
+    Methods
+    ---------
+    __init__()
+        Initializing the ParameterList.
+    extend(parameter)
+        Appends parameters from a Python iterable to the end of the list.
+    append(parameters)
+        Appends a given parameter to the end of the list.
+
+    Examples
+    ---------
+    >>> from tensorlayerx.nn import Module, ModuleList, Linear
+    >>> import tensorlayerx as tlx
+    >>> class MyModule(Module):
+    >>>     def __init__(self):
+    >>>         super(MyModule, self).__init__()
+    >>>         self.params2 = ParameterList([Parameter(tlx.ones((10,5))), Parameter(tlx.ones((5,10)))])
+    >>>     def forward(self, x):
+    >>>         x = tlx.matmul(x, self.params2[0])
+    >>>         x = tlx.matmul(x, self.params2[1])
+    >>>         return x
+    """
+
+    def __init__(self, parameters=None):
+        super(ParameterList, self).__init__()
+        if parameters is not None:
+            self += parameters
+
+    def _get_abs_string_index(self, idx):
+        if not (-len(self) <= idx < len(self)):
+            raise IndexError('index {} is out of range'.format(idx))
+        if idx < 0:
+            idx += len(self)
+        return str(idx)
+
+    def __getitem__(self, idx):
+        if isinstance(idx, slice):
+            return self.__class__(list(self._params.values())[idx])
+        else:
+            idx = self._get_abs_string_index(idx)
+            return self._params[str(idx)]
+
+    def __setitem__(self, idx, parameter):
+        idx = self._get_abs_string_index(idx)
+        self._params[str(idx)] = parameter
+
+    def __setattr__(self, key, value):
+        # if not hasattr(self, key) and not isinstance(value, tf.Variable):
+        #     warnings.warn("Setting attributes on ParameterList is not supported.")
+        super(ParameterList, self).__setattr__(key, value)
+
+    def __len__(self):
+        return len(self._params)
+
+    def __iter__(self):
+        return iter(self._params.values())
+
+    def __iadd__(self, parameters):
+        return self.extend(parameters)
+
+    def __dir__(self):
+        keys = super(ParameterList, self).__dir__()
+        keys = [key for key in keys if not key.isdigit()]
+        return keys
+
+    def append(self, parameter):
+        self.insert_param_to_layer(str(len(self)), parameter)
+        return self
+
+    def extend(self, parameters):
+        if not isinstance(parameters, container_abcs.Iterable):
+            raise TypeError(
+                "ParameterList.extend should be called with an "
+                "iterable, but got " + type(parameters).__name__
+            )
+        offset = len(self)
+        for i, para in enumerate(parameters):
+            self.insert_param_to_layer(str(offset + i), para)
+        return self
+
+    def __call__(self, input):
+        raise RuntimeError('ParameterList should not be called.')
+
+
+class ParameterDict(Module):
+    """
+    Holds parameters in a dictionary.
+
+    ParameterDict can be used like a regular Python dictionary, support
+    '__getitem__', '__setitem__', '__delitem__', '__len__', '__iter__' and '__contains__',
+
+
+    Parameters
+    ----------
+        parameters : dict
+            a mapping (dictionary) of (string: parameter)
+            or an iterable of key-value pairs of type (string, parameter)
+
+    Methods
+    ---------
+    __init__()
+        Initializing the ParameterDict.
+    clear()
+        Remove all items from the ParameterDict.
+    setdefault(key, default=None)
+        If key is in the ParameterDict, return its parameter.
+        If not, insert `key` with a parameter `default` and return `default`.
+        `default` defaults to `None`.
+    popitem()
+        Remove and return the last inserted `(key, parameter)` pair from the ParameterDict
+    pop(key)
+        Remove key from the ParameterDict and return its parameter.
+    get(key, default = None):
+        Return the parameter associated with key if present. Otherwise return default if provided, None if not.
+    fromkeys(keys, default = None)
+        Return a new ParameterDict with the keys provided
+    keys()
+        Return an iterable of the ParameterDict keys.
+    items()
+        Return an iterable of the ParameterDict key/value pairs.
+    values()
+        Return an iterable of the ParameterDict values.
+    update()
+        Update the ParameterDict with the key-value pairs from a
+        mapping or an iterable, overwriting existing keys.
+
+    Examples
+    ---------
+    >>> from tensorlayerx.nn import Module, ParameterDict, Parameter
+    >>> import tensorlayerx as tlx
+    >>> class MyModule(Module):
+    >>>     def __init__(self):
+    >>>         super(MyModule, self).__init__()
+    >>>         self.dict = ParameterDict({
+    >>>                 'left': Parameter(tlx.ones((5, 10))),
+    >>>                 'right': Parameter(tlx.zeros((5, 10)))
+    >>>                 })
+    >>>     def forward(self, x, choice):
+    >>>         x = tlx.matmul(x, self.dict[choice])
+    >>>         return x
+
+    """
+
+    def __init__(self, parameters=None):
+        super(ParameterDict, self).__init__()
+        if parameters is not None:
+            self.update(parameters)
+
+    def __getitem__(self, key):
+        return self._params[key]
+
+    def __setitem__(self, key, parameter):
+        self.insert_param_to_layer(key, parameter)
+
+    def __delitem__(self, key):
+        del self._params[key]
+
+    def __setattr__(self, key, value):
+        super(ParameterDict, self).__setattr__(key, value)
+
+    def __len__(self) -> int:
+        return len(self._params)
+
+    def __reversed__(self):
+        return reversed(list(self._params.keys()))
+
+    def __iter__(self):
+        return iter(self._params.keys())
+
+    def copy(self):
+        return ParameterDict(self._params.copy())
+
+    def __contains__(self, key):
+        return key in self._params
+
+    def setdefault(self, key, default=None):
+        if key in self._params:
+            return self._params[key]
+        self[key] = default
+        return self._params[key]
+
+    def clear(self):
+        return self._params.clear()
+
+    def pop(self, key):
+        v = self[key]
+        del self[key]
+        return v
+
+    def popitem(self):
+        return self._params.popitem()
+
+    def get(self, key, default=None):
+        return self._params.get(key, default)
+
+    def fromkeys(self, keys, default=None):
+        return ParameterDict(self._params.fromkeys(keys, default))
+
+    def keys(self):
+        return self._params.keys()
+
+    def items(self):
+        return self._params.items()
+
+    def values(self):
+        return self._params.values()
+
+    def update(self, parameters):
+        if not isinstance(parameters, container_abcs.Iterable):
+            raise TypeError(
+                "ParametersDict.update should be called with an "
+                "iterable of key/value pairs, but got " + type(parameters).__name__
+            )
+
+        if isinstance(parameters, (OrderedDict, ParameterDict)):
+            for key, parameter in parameters.items():
+                self[key] = parameter
+        elif isinstance(parameters, container_abcs.Mapping):
+            for key, parameter in sorted(parameters.items()):
+                self[key] = parameter
+        else:
+            for j, p in enumerate(parameters):
+                if not isinstance(p, container_abcs.Iterable):
+                    raise TypeError(
+                        "ParameterDict update sequence element "
+                        "#" + str(j) + " should be Iterable; is" + type(p).__name__
+                    )
+                if not len(p) == 2:
+                    raise ValueError(
+                        "ParameterDict update sequence element "
+                        "#" + str(j) + " has length " + str(len(p)) + "; 2 is required"
+                    )
+                # parameters as length-2 list too cumbersome to type, see ModuleDict.update comment
+                self[p[0]] = p[1]  # type: ignore[assignment]
+
+    def __call__(self, input):
+        raise RuntimeError('ParameterDict should not be called.')
+
 def _valid_index(layer_num, index):
     if not isinstance(index, int):
         raise TypeError("Index {} is not int type")
