@@ -5,17 +5,18 @@ from torch.nn import Module as T_Module
 from .common import check_parameter, processing_act, str2init, tolist, construct_graph, ModuleNode, select_attrs
 from .common import _save_weights, _load_weights, _save_standard_weights_dict, _load_standard_weights_dict
 from torch.nn.parameter import Parameter
-from collections import OrderedDict
+from typing import Any, Callable
 import torch
 import operator
 from itertools import islice
 from collections import OrderedDict, abc as container_abcs
+import warnings
 import tensorlayerx as tlx
 
 _global_layer_name_dict = {}
 _global_layer_node = []
 
-__all__ = ['Module', 'Sequential', 'ModuleList', 'ModuleDict']
+__all__ = ['Module', 'Sequential', 'ModuleList', 'ModuleDict', 'Parameter', 'ParameterList', 'ParameterDict']
 
 
 class Module(T_Module):
@@ -66,6 +67,10 @@ class Module(T_Module):
         # layer forward  state
         self._forward_state = False
 
+        # weights check state
+        self._check = False
+
+
     def set_train(self, mode=True):
         if not isinstance(mode, bool):
             raise ValueError("training mode is expected to be boolean")
@@ -84,8 +89,6 @@ class Module(T_Module):
         raise Exception("The forward method must be implemented by inherited class")
 
     def _get_weights(self, var_name, shape, init=None, trainable=True, transposed=None, order=False):
-        var_name = self.name + "/" + var_name
-
         if order:
             w_tmp = Parameter(init(shape), requires_grad=trainable)
             return w_tmp
@@ -102,8 +105,40 @@ class Module(T_Module):
         # TODO paramters name should be add
         _param = init(shape)
         param = Parameter(_param, requires_grad=trainable)
+        self.var_name = var_name
         return param
 
+    def _call_impl_tlx(self, *input, **kwargs):
+        if self._check == False:
+            _param_name = []
+            for name, param in self.named_parameters(recurse=True):
+                if name not in _param_name:
+                    _param_name.append(name)
+                else:
+                    raise Exception("parameter name [{}] have be been used. "
+                                    "In training, the name of layer can't be same."
+                                    "Please check the layers name".format(name))
+            self._check = True
+
+        result = self._call_impl(*input, **kwargs)
+        return result
+    # TODO RNN enabled after repair
+    __call__: Callable[..., Any] = _call_impl_tlx
+
+    def _named_members(self, get_members_fn, prefix='', recurse=True):
+        r"""Helper method for yielding various names + members of modules."""
+        memo = set()
+        modules = self.named_modules(prefix=prefix) if recurse else [(prefix, self)]
+        for module_prefix, module in modules:
+            members = get_members_fn(module)
+            for k, v in members:
+                if v is None or v in memo:
+                    continue
+                memo.add(v)
+                name = module.name + '/' + k
+                yield name, v
+
+
     @property
     def all_weights(self):
         if self._all_weights is not None and len(self._all_weights) > 0:
@@ -211,7 +246,9 @@ class Module(T_Module):
             in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
         node_index = len(_global_layer_node)
 
-        new_node = ModuleNode(self, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(self))
+        new_node = ModuleNode(
+            self, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(self)
+        )
         _global_layer_node.append(new_node)
         for idx, tensor in enumerate(outputs_list):
             tensor._info = (new_node, idx)
@@ -323,9 +360,32 @@ class Sequential(Module):
 
     def forward(self, input_data):
         for layer in self.layer_list:
+            inputs = input_data
             input_data = layer(input_data)
+            outputs = input_data
+            if not self._nodes_fixed and self._build_graph:
+                self._add_seq_node(inputs, outputs, layer)
+        self._nodes_fixed = True
         return input_data
 
+    def _add_seq_node(self, input_tensors, output_tensors, layer):
+        inputs_list = tolist(input_tensors)
+        outputs_list = tolist(output_tensors)
+        if layer.__class__.__name__ in tlx.layers.inputs.__all__:
+            in_nodes = []
+            in_tensor_idxes = [0]
+        else:
+            in_nodes = [tensor._info[0] for tensor in inputs_list]
+            in_tensor_idxes = [tensor._info[1] for tensor in inputs_list]
+        node_index = len(_global_layer_node)
+
+        new_node = ModuleNode(
+            layer, node_index, in_nodes, inputs_list, outputs_list, in_tensor_idxes, select_attrs(layer)
+        )
+        _global_layer_node.append(new_node)
+        for idx, tensor in enumerate(outputs_list):
+            tensor._info = (new_node, idx)
+
 
 class ModuleList(Module):
     """
@@ -367,7 +427,7 @@ class ModuleList(Module):
     >>> layer_list.append(d3)
     """
 
-    def __init__(self, modules = None):
+    def __init__(self, modules=None):
         super(ModuleList, self).__init__()
         if modules is not None:
             self.extend(modules)
@@ -452,7 +512,7 @@ class ModuleList(Module):
 
 class ModuleDict(Module):
 
-    def __init__(self, modules = None):
+    def __init__(self, modules=None):
         super(ModuleDict, self).__init__()
         if modules is not None:
             self.update(modules)
@@ -528,6 +588,192 @@ class ModuleDict(Module):
                 self[m[0]] = m[1]
 
 
+class ParameterList(Module):
+
+    def __init__(self, parameters=None):
+        super(ParameterList, self).__init__()
+        self._initialized = True
+        if parameters is not None:
+            self += parameters
+
+    def __setstate__(self, state):
+        state['_initialized'] = False
+        super(ParameterList, self).__setstate__(state)
+        self._initialized = True
+
+    def _get_abs_string_index(self, idx):
+        idx = operator.index(idx)
+        if not (-len(self) <= idx < len(self)):
+            raise IndexError('index {} is out of range'.format(idx))
+        if idx < 0:
+            idx += len(self)
+        return str(idx)
+
+    def __getitem__(self, idx):
+        if isinstance(idx, slice):
+            return self.__class__(list(self._parameters.values())[idx])
+        else:
+            idx = self._get_abs_string_index(idx)
+            return self._parameters[str(idx)]
+
+    def __setitem__(self, idx, param):
+        idx = self._get_abs_string_index(idx)
+        return self.register_parameter(str(idx), param)
+
+    def __setattr__(self, key, value):
+        if getattr(self, "_initialized", False):
+            if not hasattr(self, key) and not isinstance(value, torch.nn.Parameter):
+                warnings.warn("Setting attributes on ParameterList is not supported.")
+        super(ParameterList, self).__setattr__(key, value)
+
+    def __len__(self):
+        return len(self._parameters)
+
+    def __iter__(self):
+        return iter(self._parameters.values())
+
+    def __iadd__(self, parameters):
+        return self.extend(parameters)
+
+    def __dir__(self):
+        keys = super(ParameterList, self).__dir__()
+        keys = [key for key in keys if not key.isdigit()]
+        return keys
+
+    def append(self, parameter):
+
+        self.register_parameter(str(len(self)), parameter)
+        return self
+
+    def extend(self, parameters):
+        if not isinstance(parameters, container_abcs.Iterable):
+            raise TypeError(
+                "ParameterList.extend should be called with an "
+                "iterable, but got " + type(parameters).__name__
+            )
+        offset = len(self)
+        for i, param in enumerate(parameters):
+            self.register_parameter(str(offset + i), param)
+        return self
+
+    def __call__(self, input):
+        raise RuntimeError('ParameterList should not be called.')
+
+
+class ParameterDict(Module):
+
+    def __init__(self, parameters=None):
+        super(ParameterDict, self).__init__()
+        self._initialized = True
+        if parameters is not None:
+            self.update(parameters)
+
+    def __setstate__(self, state):
+        state['_initialized'] = False
+        super(ParameterDict, self).__setstate__(state)
+        self._initialized = True
+
+    def __getitem__(self, key):
+        return self._parameters[key]
+
+    def __setitem__(self, key, parameter):
+        self.register_parameter(key, parameter)
+
+    def __delitem__(self, key):
+        del self._parameters[key]
+
+    def __setattr__(self, key, value):
+        if getattr(self, "_initialized", False):
+            if not hasattr(self, key) and not isinstance(value, torch.nn.Parameter):
+                warnings.warn("Setting attributes on ParameterDict is not supported.")
+        super(ParameterDict, self).__setattr__(key, value)
+
+    def __len__(self):
+        return len(self._parameters)
+
+    def __iter__(self):
+        return iter(self._parameters.keys())
+
+    def __reversed__(self):
+        return reversed(list(self._parameters.keys()))
+
+    def copy(self):
+
+        return ParameterDict(self._parameters.copy())
+
+    def __contains__(self, key):
+        return key in self._parameters
+
+    def setdefault(self, key, default=None):
+        if key in self._parameters:
+            return self._parameters[key]
+        self[key] = default
+        return self._parameters[key]
+
+    def clear(self):
+        self._parameters.clear()
+
+    def pop(self, key):
+        v = self[key]
+        del self[key]
+        return v
+
+    def popitem(self):
+        return self._parameters.popitem()
+
+    def get(self, key, default=None):
+
+        return self._parameters.get(key, default)
+
+    def fromkeys(self, keys, default=None):
+
+        return ParameterDict(self._parameters.fromkeys(keys, default))  # type: ignore[arg-type]
+
+    def keys(self):
+
+        return self._parameters.keys()
+
+    def items(self):
+
+        return self._parameters.items()
+
+    def values(self):
+
+        return self._parameters.values()
+
+    def update(self, parameters):
+        if not isinstance(parameters, container_abcs.Iterable):
+            raise TypeError(
+                "ParametersDict.update should be called with an "
+                "iterable of key/value pairs, but got " + type(parameters).__name__
+            )
+
+        if isinstance(parameters, (OrderedDict, ParameterDict)):
+            for key, parameter in parameters.items():
+                self[key] = parameter
+        elif isinstance(parameters, container_abcs.Mapping):
+            for key, parameter in sorted(parameters.items()):
+                self[key] = parameter
+        else:
+            for j, p in enumerate(parameters):
+                if not isinstance(p, container_abcs.Iterable):
+                    raise TypeError(
+                        "ParameterDict update sequence element "
+                        "#" + str(j) + " should be Iterable; is" + type(p).__name__
+                    )
+                print(p)
+                if not len(p) == 2:
+                    raise ValueError(
+                        "ParameterDict update sequence element "
+                        "#" + str(j) + " has length " + str(len(p)) + "; 2 is required"
+                    )
+                # parameters as length-2 list too cumbersome to type, see ModuleDict.update comment
+                self[p[0]] = p[1]  # type: ignore[assignment]
+
+    def __call__(self, input):
+        raise RuntimeError('ParameterDict should not be called.')
+
+
 def _valid_index(layer_num, index):
     if not isinstance(index, int):
         raise TypeError("Index {} is not int type")
